/* A Bison parser, made by GNU Bison 2.1.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Written by Richard Stallman by simplifying the original so called
   ``semantic'' parser.  */

/* All symbols defined below should begin with conf_ or YY, to avoid
   infringing on user name space.  This should be done even for local
   variables, as they might otherwise be expanded by user macros.
   There are some unavoidable exceptions within include files to
   define necessary library symbols; they are noted "INFRINGES ON
   USER NAME SPACE" below.  */

/* Identify Bison output.  */
#define YYBISON 1

/* Bison version.  */
#define YYBISON_VERSION "2.1"

/* Skeleton name.  */
#define YYSKELETON_NAME "yacc.c"

/* Pure parsers.  */
#define YYPURE 0

/* Using locations.  */
#define YYLSP_NEEDED 0



/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum conf_tokentype {
     LEFT_BRACKET = 258,
     RIGHT_BRACKET = 259,
     EQUAL = 260,
     NEWLINE = 261,
     NONWS_STRING = 262,
     NONWSEQ_STRING = 263,
     QUOTED_NONWSEQ_STRING = 264
   };
#endif
/* Tokens.  */
#define LEFT_BRACKET 258
#define RIGHT_BRACKET 259
#define EQUAL 260
#define NEWLINE 261
#define NONWS_STRING 262
#define NONWSEQ_STRING 263
#define QUOTED_NONWSEQ_STRING 264




/* Copy the first part of user declarations.  */
#line 44 "conf_parse.y"

#ifdef HAVE_CONFIG_H
# include <config.h>
#endif /* HAVE_CONFIG_H */
#include <am_defs.h>
#include <amd.h>

extern char *conf_text;
extern int aconf_lineno;
extern int conf_lex(void);

static int conf_error(const char *s);
static int retval;
static char *header_section = NULL; /* start with no header section */

#define YYDEBUG 1

#define PARSE_DEBUG 0

#if PARSE_DEBUG
# define dprintf(f,s) fprintf(stderr, (f), aconf_lineno, (s))
# define amu_return(v)
#else /* not PARSE_DEBUG */
# define dprintf(f,s)
# define amu_return(v) return((v))
#endif /* not PARSE_DEBUG */



/* Enabling traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif

/* Enabling verbose error messages.  */
#ifdef YYERROR_VERBOSE
# undef YYERROR_VERBOSE
# define YYERROR_VERBOSE 1
#else
# define YYERROR_VERBOSE 0
#endif

/* Enabling the token table.  */
#ifndef YYTOKEN_TABLE
# define YYTOKEN_TABLE 0
#endif

#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 73 "conf_parse.y"
typedef union YYSTYPE {
char *strtype;
} YYSTYPE;
/* Line 196 of yacc.c.  */
#line 136 "conf_parse.c"
# define conf_stype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif



/* Copy the second part of user declarations.  */


/* Line 219 of yacc.c.  */
#line 148 "conf_parse.c"

#if ! defined (YYSIZE_T) && defined (__SIZE_TYPE__)
# define YYSIZE_T __SIZE_TYPE__
#endif
#if ! defined (YYSIZE_T) && defined (size_t)
# define YYSIZE_T size_t
#endif
#if ! defined (YYSIZE_T) && (defined (__STDC__) || defined (__cplusplus))
# include <stddef.h> /* INFRINGES ON USER NAME SPACE */
# define YYSIZE_T size_t
#endif
#if ! defined (YYSIZE_T)
# define YYSIZE_T unsigned int
#endif

#ifndef YY_
# if YYENABLE_NLS
#  if ENABLE_NLS
#   include <libintl.h> /* INFRINGES ON USER NAME SPACE */
#   define YY_(msgid) dgettext ("bison-runtime", msgid)
#  endif
# endif
# ifndef YY_
#  define YY_(msgid) msgid
# endif
#endif

#if ! defined (conf_overflow) || YYERROR_VERBOSE

/* The parser invokes alloca or malloc; define the necessary symbols.  */

# ifdef YYSTACK_USE_ALLOCA
#  if YYSTACK_USE_ALLOCA
#   ifdef __GNUC__
#    define YYSTACK_ALLOC __builtin_alloca
#   else
#    define YYSTACK_ALLOC alloca
#    if defined (__STDC__) || defined (__cplusplus)
#     include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
#     define YYINCLUDED_STDLIB_H
#    endif
#   endif
#  endif
# endif

# ifdef YYSTACK_ALLOC
   /* Pacify GCC's `empty if-body' warning. */
#  define YYSTACK_FREE(Ptr) do { /* empty */; } while (0)
#  ifndef YYSTACK_ALLOC_MAXIMUM
    /* The OS might guarantee only one guard page at the bottom of the stack,
       and a page size can be as small as 4096 bytes.  So we cannot safely
       invoke alloca (N) if N exceeds 4096.  Use a slightly smaller number
       to allow for a few compiler-allocated temporary stack slots.  */
#   define YYSTACK_ALLOC_MAXIMUM 4032 /* reasonable circa 2005 */
#  endif
# else
#  define YYSTACK_ALLOC YYMALLOC
#  define YYSTACK_FREE YYFREE
#  ifndef YYSTACK_ALLOC_MAXIMUM
#   define YYSTACK_ALLOC_MAXIMUM ((YYSIZE_T) -1)
#  endif
#  ifdef __cplusplus
extern "C" {
#  endif
#  ifndef YYMALLOC
#   define YYMALLOC malloc
#   if (! defined (malloc) && ! defined (YYINCLUDED_STDLIB_H) \
	&& (defined (__STDC__) || defined (__cplusplus)))
void *malloc (YYSIZE_T); /* INFRINGES ON USER NAME SPACE */
#   endif
#  endif
#  ifndef YYFREE
#   define YYFREE free
#   if (! defined (free) && ! defined (YYINCLUDED_STDLIB_H) \
	&& (defined (__STDC__) || defined (__cplusplus)))
void free (void *); /* INFRINGES ON USER NAME SPACE */
#   endif
#  endif
#  ifdef __cplusplus
}
#  endif
# endif
#endif /* ! defined (conf_overflow) || YYERROR_VERBOSE */


#if (! defined (conf_overflow) \
     && (! defined (__cplusplus) \
	 || (defined (YYSTYPE_IS_TRIVIAL) && YYSTYPE_IS_TRIVIAL)))

/* A type that is properly aligned for any stack member.  */
union conf_alloc
{
  short int conf_ss;
  YYSTYPE conf_vs;
  };

/* The size of the maximum gap between one aligned stack and the next.  */
# define YYSTACK_GAP_MAXIMUM (sizeof (union conf_alloc) - 1)

/* The size of an array large to enough to hold all stacks, each with
   N elements.  */
# define YYSTACK_BYTES(N) \
     ((N) * (sizeof (short int) + sizeof (YYSTYPE))			\
      + YYSTACK_GAP_MAXIMUM)

/* Copy COUNT objects from FROM to TO.  The source and destination do
   not overlap.  */
# ifndef YYCOPY
#  if defined (__GNUC__) && 1 < __GNUC__
#   define YYCOPY(To, From, Count) \
      __builtin_memcpy (To, From, (Count) * sizeof (*(From)))
#  else
#   define YYCOPY(To, From, Count)		\
      do					\
	{					\
	  YYSIZE_T conf_i;				\
	  for (conf_i = 0; conf_i < (Count); conf_i++)	\
	    (To)[conf_i] = (From)[conf_i];		\
	}					\
      while (0)
#  endif
# endif

/* Relocate STACK from its old location to the new one.  The
   local variables YYSIZE and YYSTACKSIZE give the old and new number of
   elements in the stack, and YYPTR gives the new location of the
   stack.  Advance YYPTR to a properly aligned location for the next
   stack.  */
# define YYSTACK_RELOCATE(Stack)					\
    do									\
      {									\
	YYSIZE_T conf_newbytes;						\
	YYCOPY (&conf_ptr->Stack, Stack, conf_size);				\
	Stack = &conf_ptr->Stack;						\
	conf_newbytes = conf_stacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
	conf_ptr += conf_newbytes / sizeof (*conf_ptr);				\
      }									\
    while (0)

#endif

#if defined (__STDC__) || defined (__cplusplus)
   typedef signed char conf_signed_char;
#else
   typedef short int conf_signed_char;
#endif

/* YYFINAL -- State number of the termination state. */
#define YYFINAL  4
/* YYLAST -- Last index in YYTABLE.  */
#define YYLAST   20

/* YYNTOKENS -- Number of terminals. */
#define YYNTOKENS  10
/* YYNNTS -- Number of nonterminals. */
#define YYNNTS  10
/* YYNRULES -- Number of rules. */
#define YYNRULES  17
/* YYNRULES -- Number of states. */
#define YYNSTATES  29

/* YYTRANSLATE(YYLEX) -- Bison symbol number corresponding to YYLEX.  */
#define YYUNDEFTOK  2
#define YYMAXUTOK   264

#define YYTRANSLATE(YYX)						\
  ((unsigned int) (YYX) <= YYMAXUTOK ? conf_translate[YYX] : YYUNDEFTOK)

/* YYTRANSLATE[YYLEX] -- Bison symbol number corresponding to YYLEX.  */
static const unsigned char conf_translate[] =
{
       0,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     1,     2,     3,     4,
       5,     6,     7,     8,     9
};

#if YYDEBUG
/* YYPRHS[YYN] -- Index of the first RHS symbol of rule number YYN in
   YYRHS.  */
static const unsigned char conf_prhs[] =
{
       0,     0,     3,     4,     8,     9,    12,    14,    17,    19,
      22,    25,    30,    32,    35,    40,    45,    50
};

/* YYRHS -- A `-1'-separated list of the rules' RHS. */
static const conf_signed_char conf_rhs[] =
{
      11,     0,    -1,    -1,    12,    14,    15,    -1,    -1,    13,
      15,    -1,     6,    -1,     6,    14,    -1,    16,    -1,    16,
      15,    -1,    17,    18,    -1,     3,     7,     4,     6,    -1,
      19,    -1,    19,    18,    -1,     7,     5,     7,     6,    -1,
       7,     5,     8,     6,    -1,     7,     5,     9,     6,    -1,
       6,    -1
};

/* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
static const unsigned char conf_rline[] =
{
       0,    87,    87,    87,    88,    88,    91,    92,    95,    96,
      99,   102,   110,   111,   114,   124,   134,   144
};
#endif

#if YYDEBUG || YYERROR_VERBOSE || YYTOKEN_TABLE
/* YYTNAME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
   First, the terminals, then, starting at YYNTOKENS, nonterminals. */
static const char *const conf_tname[] =
{
  "$end", "error", "$undefined", "LEFT_BRACKET", "RIGHT_BRACKET", "EQUAL",
  "NEWLINE", "NONWS_STRING", "NONWSEQ_STRING", "QUOTED_NONWSEQ_STRING",
  "$accept", "file", "@1", "@2", "newlines", "map_sections", "map_section",
  "sec_header", "kv_pairs", "kv_pair", 0
};
#endif

# ifdef YYPRINT
/* YYTOKNUM[YYLEX-NUM] -- Internal token number corresponding to
   token YYLEX-NUM.  */
static const unsigned short int conf_toknum[] =
{
       0,   256,   257,   258,   259,   260,   261,   262,   263,   264
};
# endif

/* YYR1[YYN] -- Symbol number of symbol that rule YYN derives.  */
static const unsigned char conf_r1[] =
{
       0,    10,    12,    11,    13,    11,    14,    14,    15,    15,
      16,    17,    18,    18,    19,    19,    19,    19
};

/* YYR2[YYN] -- Number of symbols composing right hand side of rule YYN.  */
static const unsigned char conf_r2[] =
{
       0,     2,     0,     3,     0,     2,     1,     2,     1,     2,
       2,     4,     1,     2,     4,     4,     4,     1
};

/* YYDEFACT[STATE-NAME] -- Default rule to reduce with in state
   STATE-NUM when YYTABLE doesn't specify something else to do.  Zero
   means the default is an error.  */
static const unsigned char conf_defact[] =
{
       2,     0,     0,     0,     1,     6,     0,     0,     5,     8,
       0,     7,     3,     0,     9,    17,     0,    10,    12,     0,
       0,    13,    11,     0,     0,     0,    14,    15,    16
};

/* YYDEFGOTO[NTERM-NUM]. */
static const conf_signed_char conf_defgoto[] =
{
      -1,     1,     2,     3,     6,     8,     9,    10,    17,    18
};

/* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
   STATE-NUM.  */
#define YYPACT_NINF -7
static const conf_signed_char conf_pact[] =
{
       4,     8,     3,     7,    -7,     3,     7,     5,    -7,     7,
      -5,    -7,    -7,     9,    -7,    -7,     6,    -7,    -5,    10,
      -3,    -7,    -7,    11,    12,    13,    -7,    -7,    -7
};

/* YYPGOTO[NTERM-NUM].  */
static const conf_signed_char conf_pgoto[] =
{
      -7,    -7,    -7,    -7,    15,    -6,    -7,    -7,    -4,    -7
};

/* YYTABLE[YYPACT[STATE-NUM]].  What to do in state STATE-NUM.  If
   positive, shift that token.  If negative, reduce the rule which
   number is the opposite.  If zero, do what YYDEFACT says.
   If YYTABLE_NINF, syntax error.  */
#define YYTABLE_NINF -5
static const conf_signed_char conf_table[] =
{
      12,    15,    16,    14,    23,    24,    25,    -4,     4,     5,
       7,    20,    13,    19,    21,     0,    22,    26,    27,    28,
      11
};

static const conf_signed_char conf_check[] =
{
       6,     6,     7,     9,     7,     8,     9,     3,     0,     6,
       3,     5,     7,     4,    18,    -1,     6,     6,     6,     6,
       5
};

/* YYSTOS[STATE-NUM] -- The (internal number of the) accessing
   symbol of state STATE-NUM.  */
static const unsigned char conf_stos[] =
{
       0,    11,    12,    13,     0,     6,    14,     3,    15,    16,
      17,    14,    15,     7,    15,     6,     7,    18,    19,     4,
       5,    18,     6,     7,     8,     9,     6,     6,     6
};

#define conf_errok		(conf_errstatus = 0)
#define conf_clearin	(conf_char = YYEMPTY)
#define YYEMPTY		(-2)
#define YYEOF		0

#define YYACCEPT	goto conf_acceptlab
#define YYABORT		goto conf_abortlab
#define YYERROR		goto conf_errorlab


/* Like YYERROR except do call conf_error.  This remains here temporarily
   to ease the transition to the new meaning of YYERROR, for GCC.
   Once GCC version 2 has supplanted version 1, this can go.  */

#define YYFAIL		goto conf_errlab

#define YYRECOVERING()  (!!conf_errstatus)

#define YYBACKUP(Token, Value)					\
do								\
  if (conf_char == YYEMPTY && conf_len == 1)				\
    {								\
      conf_char = (Token);						\
      conf_lval = (Value);						\
      conf_token = YYTRANSLATE (conf_char);				\
      YYPOPSTACK;						\
      goto conf_backup;						\
    }								\
  else								\
    {								\
      conf_error (YY_("syntax error: cannot back up")); \
      YYERROR;							\
    }								\
while (0)


#define YYTERROR	1
#define YYERRCODE	256


/* YYLLOC_DEFAULT -- Set CURRENT to span from RHS[1] to RHS[N].
   If N is 0, then set CURRENT to the empty location which ends
   the previous symbol: RHS[0] (always defined).  */

#define YYRHSLOC(Rhs, K) ((Rhs)[K])
#ifndef YYLLOC_DEFAULT
# define YYLLOC_DEFAULT(Current, Rhs, N)				\
    do									\
      if (N)								\
	{								\
	  (Current).first_line   = YYRHSLOC (Rhs, 1).first_line;	\
	  (Current).first_column = YYRHSLOC (Rhs, 1).first_column;	\
	  (Current).last_line    = YYRHSLOC (Rhs, N).last_line;		\
	  (Current).last_column  = YYRHSLOC (Rhs, N).last_column;	\
	}								\
      else								\
	{								\
	  (Current).first_line   = (Current).last_line   =		\
	    YYRHSLOC (Rhs, 0).last_line;				\
	  (Current).first_column = (Current).last_column =		\
	    YYRHSLOC (Rhs, 0).last_column;				\
	}								\
    while (0)
#endif


/* YY_LOCATION_PRINT -- Print the location on the stream.
   This macro was not mandated originally: define only if we know
   we won't break user code: when these are the locations we know.  */

#ifndef YY_LOCATION_PRINT
# if YYLTYPE_IS_TRIVIAL
#  define YY_LOCATION_PRINT(File, Loc)			\
     fprintf (File, "%d.%d-%d.%d",			\
              (Loc).first_line, (Loc).first_column,	\
              (Loc).last_line,  (Loc).last_column)
# else
#  define YY_LOCATION_PRINT(File, Loc) ((void) 0)
# endif
#endif


/* YYLEX -- calling `conf_lex' with the right arguments.  */

#ifdef YYLEX_PARAM
# define YYLEX conf_lex (YYLEX_PARAM)
#else
# define YYLEX conf_lex ()
#endif

/* Enable debugging if requested.  */
#if YYDEBUG

# ifndef YYFPRINTF
#  include <stdio.h> /* INFRINGES ON USER NAME SPACE */
#  define YYFPRINTF fprintf
# endif

# define YYDPRINTF(Args)			\
do {						\
  if (conf_debug)					\
    YYFPRINTF Args;				\
} while (0)

# define YY_SYMBOL_PRINT(Title, Type, Value, Location)		\
do {								\
  if (conf_debug)							\
    {								\
      YYFPRINTF (stderr, "%s ", Title);				\
      conf_symprint (stderr,					\
                  Type, Value);	\
      YYFPRINTF (stderr, "\n");					\
    }								\
} while (0)

/*------------------------------------------------------------------.
| conf__stack_print -- Print the state stack from its BOTTOM up to its |
| TOP (included).                                                   |
`------------------------------------------------------------------*/

#if defined (__STDC__) || defined (__cplusplus)
static void
conf__stack_print (short int *bottom, short int *top)
#else
static void
conf__stack_print (bottom, top)
    short int *bottom;
    short int *top;
#endif
{
  YYFPRINTF (stderr, "Stack now");
  for (/* Nothing. */; bottom <= top; ++bottom)
    YYFPRINTF (stderr, " %d", *bottom);
  YYFPRINTF (stderr, "\n");
}

# define YY_STACK_PRINT(Bottom, Top)				\
do {								\
  if (conf_debug)							\
    conf__stack_print ((Bottom), (Top));				\
} while (0)


/*------------------------------------------------.
| Report that the YYRULE is going to be reduced.  |
`------------------------------------------------*/

#if defined (__STDC__) || defined (__cplusplus)
static void
conf__reduce_print (int conf_rule)
#else
static void
conf__reduce_print (conf_rule)
    int conf_rule;
#endif
{
  int conf_i;
  unsigned long int conf_lno = conf_rline[conf_rule];
  YYFPRINTF (stderr, "Reducing stack by rule %d (line %lu), ",
             conf_rule - 1, conf_lno);
  /* Print the symbols being reduced, and their result.  */
  for (conf_i = conf_prhs[conf_rule]; 0 <= conf_rhs[conf_i]; conf_i++)
    YYFPRINTF (stderr, "%s ", conf_tname[conf_rhs[conf_i]]);
  YYFPRINTF (stderr, "-> %s\n", conf_tname[conf_r1[conf_rule]]);
}

# define YY_REDUCE_PRINT(Rule)		\
do {					\
  if (conf_debug)				\
    conf__reduce_print (Rule);		\
} while (0)

/* Nonzero means print parse trace.  It is left uninitialized so that
   multiple parsers can coexist.  */
int conf_debug;
#else /* !YYDEBUG */
# define YYDPRINTF(Args)
# define YY_SYMBOL_PRINT(Title, Type, Value, Location)
# define YY_STACK_PRINT(Bottom, Top)
# define YY_REDUCE_PRINT(Rule)
#endif /* !YYDEBUG */


/* YYINITDEPTH -- initial size of the parser's stacks.  */
#ifndef	YYINITDEPTH
# define YYINITDEPTH 200
#endif

/* YYMAXDEPTH -- maximum size the stacks can grow to (effective only
   if the built-in stack extension method is used).

   Do not make this value too large; the results are undefined if
   YYSTACK_ALLOC_MAXIMUM < YYSTACK_BYTES (YYMAXDEPTH)
   evaluated with infinite-precision integer arithmetic.  */

#ifndef YYMAXDEPTH
# define YYMAXDEPTH 10000
#endif



#if YYERROR_VERBOSE

# ifndef conf_strlen
#  if defined (__GLIBC__) && defined (_STRING_H)
#   define conf_strlen strlen
#  else
/* Return the length of YYSTR.  */
static YYSIZE_T
#   if defined (__STDC__) || defined (__cplusplus)
conf_strlen (const char *conf_str)
#   else
conf_strlen (conf_str)
     const char *conf_str;
#   endif
{
  const char *conf_s = conf_str;

  while (*conf_s++ != '\0')
    continue;

  return conf_s - conf_str - 1;
}
#  endif
# endif

# ifndef conf_stpcpy
#  if defined (__GLIBC__) && defined (_STRING_H) && defined (_GNU_SOURCE)
#   define conf_stpcpy stpcpy
#  else
/* Copy YYSRC to YYDEST, returning the address of the terminating '\0' in
   YYDEST.  */
static char *
#   if defined (__STDC__) || defined (__cplusplus)
conf_stpcpy (char *conf_dest, const char *conf_src)
#   else
conf_stpcpy (conf_dest, conf_src)
     char *conf_dest;
     const char *conf_src;
#   endif
{
  char *conf_d = conf_dest;
  const char *conf_s = conf_src;

  while ((*conf_d++ = *conf_s++) != '\0')
    continue;

  return conf_d - 1;
}
#  endif
# endif

# ifndef conf_tnamerr
/* Copy to YYRES the contents of YYSTR after stripping away unnecessary
   quotes and backslashes, so that it's suitable for conf_error.  The
   heuristic is that double-quoting is unnecessary unless the string
   contains an apostrophe, a comma, or backslash (other than
   backslash-backslash).  YYSTR is taken from conf_tname.  If YYRES is
   null, do not copy; instead, return the length of what the result
   would have been.  */
static YYSIZE_T
conf_tnamerr (char *conf_res, const char *conf_str)
{
  if (*conf_str == '"')
    {
      size_t conf_n = 0;
      char const *conf_p = conf_str;

      for (;;)
	switch (*++conf_p)
	  {
	  case '\'':
	  case ',':
	    goto do_not_strip_quotes;

	  case '\\':
	    if (*++conf_p != '\\')
	      goto do_not_strip_quotes;
	    /* Fall through.  */
	  default:
	    if (conf_res)
	      conf_res[conf_n] = *conf_p;
	    conf_n++;
	    break;

	  case '"':
	    if (conf_res)
	      conf_res[conf_n] = '\0';
	    return conf_n;
	  }
    do_not_strip_quotes: ;
    }

  if (! conf_res)
    return conf_strlen (conf_str);

  return conf_stpcpy (conf_res, conf_str) - conf_res;
}
# endif

#endif /* YYERROR_VERBOSE */



#if YYDEBUG
/*--------------------------------.
| Print this symbol on YYOUTPUT.  |
`--------------------------------*/

#if defined (__STDC__) || defined (__cplusplus)
static void
conf_symprint (FILE *conf_output, int conf_type, YYSTYPE *conf_valuep)
#else
static void
conf_symprint (conf_output, conf_type, conf_valuep)
    FILE *conf_output;
    int conf_type;
    YYSTYPE *conf_valuep;
#endif
{
  /* Pacify ``unused variable'' warnings.  */
  (void) conf_valuep;

  if (conf_type < YYNTOKENS)
    YYFPRINTF (conf_output, "token %s (", conf_tname[conf_type]);
  else
    YYFPRINTF (conf_output, "nterm %s (", conf_tname[conf_type]);


# ifdef YYPRINT
  if (conf_type < YYNTOKENS)
    YYPRINT (conf_output, conf_toknum[conf_type], *conf_valuep);
# endif
  switch (conf_type)
    {
      default:
        break;
    }
  YYFPRINTF (conf_output, ")");
}

#endif /* ! YYDEBUG */
/*-----------------------------------------------.
| Release the memory associated to this symbol.  |
`-----------------------------------------------*/

#if defined (__STDC__) || defined (__cplusplus)
static void
conf_destruct (const char *conf_msg, int conf_type, YYSTYPE *conf_valuep)
#else
static void
conf_destruct (conf_msg, conf_type, conf_valuep)
    const char *conf_msg;
    int conf_type;
    YYSTYPE *conf_valuep;
#endif
{
  /* Pacify ``unused variable'' warnings.  */
  (void) conf_valuep;

  if (!conf_msg)
    conf_msg = "Deleting";
  YY_SYMBOL_PRINT (conf_msg, conf_type, conf_valuep, conf_locationp);

  switch (conf_type)
    {

      default:
        break;
    }
}


/* Prevent warnings from -Wmissing-prototypes.  */

#ifdef YYPARSE_PARAM
# if defined (__STDC__) || defined (__cplusplus)
int conf_parse (void *YYPARSE_PARAM);
# else
int conf_parse ();
# endif
#else /* ! YYPARSE_PARAM */
#if defined (__STDC__) || defined (__cplusplus)
int conf_parse (void);
#else
int conf_parse ();
#endif
#endif /* ! YYPARSE_PARAM */



/* The look-ahead symbol.  */
int conf_char;

/* The semantic value of the look-ahead symbol.  */
YYSTYPE conf_lval;

/* Number of syntax errors so far.  */
int conf_nerrs;



/*----------.
| conf_parse.  |
`----------*/

#ifdef YYPARSE_PARAM
# if defined (__STDC__) || defined (__cplusplus)
int conf_parse (void *YYPARSE_PARAM)
# else
int conf_parse (YYPARSE_PARAM)
  void *YYPARSE_PARAM;
# endif
#else /* ! YYPARSE_PARAM */
#if defined (__STDC__) || defined (__cplusplus)
int
conf_parse (void)
#else
int
conf_parse ()
    ;
#endif
#endif
{
  
  int conf_state;
  int conf_n;
  int conf_result;
  /* Number of tokens to shift before error messages enabled.  */
  int conf_errstatus;
  /* Look-ahead token as an internal (translated) token number.  */
  int conf_token = 0;

  /* Three stacks and their tools:
     `conf_ss': related to states,
     `conf_vs': related to semantic values,
     `conf_ls': related to locations.

     Refer to the stacks thru separate pointers, to allow conf_overflow
     to reallocate them elsewhere.  */

  /* The state stack.  */
  short int conf_ssa[YYINITDEPTH];
  short int *conf_ss = conf_ssa;
  short int *conf_ssp;

  /* The semantic value stack.  */
  YYSTYPE conf_vsa[YYINITDEPTH];
  YYSTYPE *conf_vs = conf_vsa;
  YYSTYPE *conf_vsp;



#define YYPOPSTACK   (conf_vsp--, conf_ssp--)

  YYSIZE_T conf_stacksize = YYINITDEPTH;

  /* The variables used to return semantic value and location from the
     action routines.  */
  YYSTYPE conf_val;


  /* When reducing, the number of symbols on the RHS of the reduced
     rule.  */
  int conf_len;

  YYDPRINTF ((stderr, "Starting parse\n"));

  conf_state = 0;
  conf_errstatus = 0;
  conf_nerrs = 0;
  conf_char = YYEMPTY;		/* Cause a token to be read.  */

  /* Initialize stack pointers.
     Waste one element of value and location stack
     so that they stay on the same level as the state stack.
     The wasted elements are never initialized.  */

  conf_ssp = conf_ss;
  conf_vsp = conf_vs;

  goto conf_setstate;

/*------------------------------------------------------------.
| conf_newstate -- Push a new state, which is found in conf_state.  |
`------------------------------------------------------------*/
 conf_newstate:
  /* In all cases, when you get here, the value and location stacks
     have just been pushed. so pushing a state here evens the stacks.
     */
  conf_ssp++;

 conf_setstate:
  *conf_ssp = conf_state;

  if (conf_ss + conf_stacksize - 1 <= conf_ssp)
    {
      /* Get the current used size of the three stacks, in elements.  */
      YYSIZE_T conf_size = conf_ssp - conf_ss + 1;

#ifdef conf_overflow
      {
	/* Give user a chance to reallocate the stack. Use copies of
	   these so that the &'s don't force the real ones into
	   memory.  */
	YYSTYPE *conf_vs1 = conf_vs;
	short int *conf_ss1 = conf_ss;


	/* Each stack pointer address is followed by the size of the
	   data in use in that stack, in bytes.  This used to be a
	   conditional around just the two extra args, but that might
	   be undefined if conf_overflow is a macro.  */
	conf_overflow (YY_("memory exhausted"),
		    &conf_ss1, conf_size * sizeof (*conf_ssp),
		    &conf_vs1, conf_size * sizeof (*conf_vsp),

		    &conf_stacksize);

	conf_ss = conf_ss1;
	conf_vs = conf_vs1;
      }
#else /* no conf_overflow */
# ifndef YYSTACK_RELOCATE
      goto conf_exhaustedlab;
# else
      /* Extend the stack our own way.  */
      if (YYMAXDEPTH <= conf_stacksize)
	goto conf_exhaustedlab;
      conf_stacksize *= 2;
      if (YYMAXDEPTH < conf_stacksize)
	conf_stacksize = YYMAXDEPTH;

      {
	short int *conf_ss1 = conf_ss;
	union conf_alloc *conf_ptr =
	  (union conf_alloc *) YYSTACK_ALLOC (YYSTACK_BYTES (conf_stacksize));
	if (! conf_ptr)
	  goto conf_exhaustedlab;
	YYSTACK_RELOCATE (conf_ss);
	YYSTACK_RELOCATE (conf_vs);

#  undef YYSTACK_RELOCATE
	if (conf_ss1 != conf_ssa)
	  YYSTACK_FREE (conf_ss1);
      }
# endif
#endif /* no conf_overflow */

      conf_ssp = conf_ss + conf_size - 1;
      conf_vsp = conf_vs + conf_size - 1;


      YYDPRINTF ((stderr, "Stack size increased to %lu\n",
		  (unsigned long int) conf_stacksize));

      if (conf_ss + conf_stacksize - 1 <= conf_ssp)
	YYABORT;
    }

  YYDPRINTF ((stderr, "Entering state %d\n", conf_state));

  goto conf_backup;

/*-----------.
| conf_backup.  |
`-----------*/
conf_backup:

/* Do appropriate processing given the current state.  */
/* Read a look-ahead token if we need one and don't already have one.  */
/* conf_resume: */

  /* First try to decide what to do without reference to look-ahead token.  */

  conf_n = conf_pact[conf_state];
  if (conf_n == YYPACT_NINF)
    goto conf_default;

  /* Not known => get a look-ahead token if don't already have one.  */

  /* YYCHAR is either YYEMPTY or YYEOF or a valid look-ahead symbol.  */
  if (conf_char == YYEMPTY)
    {
      YYDPRINTF ((stderr, "Reading a token: "));
      conf_char = YYLEX;
    }

  if (conf_char <= YYEOF)
    {
      conf_char = conf_token = YYEOF;
      YYDPRINTF ((stderr, "Now at end of input.\n"));
    }
  else
    {
      conf_token = YYTRANSLATE (conf_char);
      YY_SYMBOL_PRINT ("Next token is", conf_token, &conf_lval, &conf_lloc);
    }

  /* If the proper action on seeing token YYTOKEN is to reduce or to
     detect an error, take that action.  */
  conf_n += conf_token;
  if (conf_n < 0 || YYLAST < conf_n || conf_check[conf_n] != conf_token)
    goto conf_default;
  conf_n = conf_table[conf_n];
  if (conf_n <= 0)
    {
      if (conf_n == 0 || conf_n == YYTABLE_NINF)
	goto conf_errlab;
      conf_n = -conf_n;
      goto conf_reduce;
    }

  if (conf_n == YYFINAL)
    YYACCEPT;

  /* Shift the look-ahead token.  */
  YY_SYMBOL_PRINT ("Shifting", conf_token, &conf_lval, &conf_lloc);

  /* Discard the token being shifted unless it is eof.  */
  if (conf_char != YYEOF)
    conf_char = YYEMPTY;

  *++conf_vsp = conf_lval;


  /* Count tokens shifted since error; after three, turn off error
     status.  */
  if (conf_errstatus)
    conf_errstatus--;

  conf_state = conf_n;
  goto conf_newstate;


/*-----------------------------------------------------------.
| conf_default -- do the default action for the current state.  |
`-----------------------------------------------------------*/
conf_default:
  conf_n = conf_defact[conf_state];
  if (conf_n == 0)
    goto conf_errlab;
  goto conf_reduce;


/*-----------------------------.
| conf_reduce -- Do a reduction.  |
`-----------------------------*/
conf_reduce:
  /* conf_n is the number of a rule to reduce with.  */
  conf_len = conf_r2[conf_n];

  /* If YYLEN is nonzero, implement the default value of the action:
     `$$ = $1'.

     Otherwise, the following line sets YYVAL to garbage.
     This behavior is undocumented and Bison
     users should not rely upon it.  Assigning to YYVAL
     unconditionally makes the parser a bit smaller, and it avoids a
     GCC warning that YYVAL may be used uninitialized.  */
  conf_val = conf_vsp[1-conf_len];


  YY_REDUCE_PRINT (conf_n);
  switch (conf_n)
    {
        case 2:
#line 87 "conf_parse.y"
    { conf_debug = PARSE_DEBUG; }
    break;

  case 4:
#line 88 "conf_parse.y"
    { conf_debug = PARSE_DEBUG; }
    break;

  case 11:
#line 103 "conf_parse.y"
    {
		  if (conf_debug)
		    fprintf(stderr, "sec_header1 = \"%s\"\n", (conf_vsp[-2].strtype));
		  header_section = (conf_vsp[-2].strtype);
		}
    break;

  case 14:
#line 115 "conf_parse.y"
    {
		  if (conf_debug)
		    fprintf(stderr,"parse1: key=\"%s\", val=\"%s\"\n", (conf_vsp[-3].strtype), (conf_vsp[-1].strtype));
		  retval = set_conf_kv(header_section, (conf_vsp[-3].strtype), (conf_vsp[-1].strtype));
		  if (retval != 0) {
		    conf_error("syntax error");
		    YYABORT;
		  }
		}
    break;

  case 15:
#line 125 "conf_parse.y"
    {
		  if (conf_debug)
		    fprintf(stderr,"parse2: key=\"%s\", val=\"%s\"\n", (conf_vsp[-3].strtype), (conf_vsp[-1].strtype));
		  retval = set_conf_kv(header_section, (conf_vsp[-3].strtype), (conf_vsp[-1].strtype));
		  if (retval != 0) {
		    conf_error("syntax error");
		    YYABORT;
		  }
		}
    break;

  case 16:
#line 135 "conf_parse.y"
    {
		  if (conf_debug)
		    fprintf(stderr,"parse3: key=\"%s\", val=\"%s\"\n", (conf_vsp[-3].strtype), (conf_vsp[-1].strtype));
		  retval = set_conf_kv(header_section, (conf_vsp[-3].strtype), (conf_vsp[-1].strtype));
		  if (retval != 0) {
		    conf_error("syntax error");
		    YYABORT;
		  }
		}
    break;


      default: break;
    }

/* Line 1126 of yacc.c.  */
#line 1201 "conf_parse.c"

  conf_vsp -= conf_len;
  conf_ssp -= conf_len;


  YY_STACK_PRINT (conf_ss, conf_ssp);

  *++conf_vsp = conf_val;


  /* Now `shift' the result of the reduction.  Determine what state
     that goes to, based on the state we popped back to and the rule
     number reduced by.  */

  conf_n = conf_r1[conf_n];

  conf_state = conf_pgoto[conf_n - YYNTOKENS] + *conf_ssp;
  if (0 <= conf_state && conf_state <= YYLAST && conf_check[conf_state] == *conf_ssp)
    conf_state = conf_table[conf_state];
  else
    conf_state = conf_defgoto[conf_n - YYNTOKENS];

  goto conf_newstate;


/*------------------------------------.
| conf_errlab -- here on detecting error |
`------------------------------------*/
conf_errlab:
  /* If not already recovering from an error, report this error.  */
  if (!conf_errstatus)
    {
      ++conf_nerrs;
#if YYERROR_VERBOSE
      conf_n = conf_pact[conf_state];

      if (YYPACT_NINF < conf_n && conf_n < YYLAST)
	{
	  int conf_type = YYTRANSLATE (conf_char);
	  YYSIZE_T conf_size0 = conf_tnamerr (0, conf_tname[conf_type]);
	  YYSIZE_T conf_size = conf_size0;
	  YYSIZE_T conf_size1;
	  int conf_size_overflow = 0;
	  char *conf_msg = 0;
#	  define YYERROR_VERBOSE_ARGS_MAXIMUM 5
	  char const *conf_arg[YYERROR_VERBOSE_ARGS_MAXIMUM];
	  int conf_x;

#if 0
	  /* This is so xgettext sees the translatable formats that are
	     constructed on the fly.  */
	  YY_("syntax error, unexpected %s");
	  YY_("syntax error, unexpected %s, expecting %s");
	  YY_("syntax error, unexpected %s, expecting %s or %s");
	  YY_("syntax error, unexpected %s, expecting %s or %s or %s");
	  YY_("syntax error, unexpected %s, expecting %s or %s or %s or %s");
#endif
	  char *conf_fmt;
	  char const *conf_f;
	  static char const conf_unexpected[] = "syntax error, unexpected %s";
	  static char const conf_expecting[] = ", expecting %s";
	  static char const conf_or[] = " or %s";
	  char conf_format[sizeof conf_unexpected
			+ sizeof conf_expecting - 1
			+ ((YYERROR_VERBOSE_ARGS_MAXIMUM - 2)
			   * (sizeof conf_or - 1))];
	  char const *conf_prefix = conf_expecting;

	  /* Start YYX at -YYN if negative to avoid negative indexes in
	     YYCHECK.  */
	  int conf_xbegin = conf_n < 0 ? -conf_n : 0;

	  /* Stay within bounds of both conf_check and conf_tname.  */
	  int conf_checklim = YYLAST - conf_n;
	  int conf_xend = conf_checklim < YYNTOKENS ? conf_checklim : YYNTOKENS;
	  int conf_count = 1;

	  conf_arg[0] = conf_tname[conf_type];
	  conf_fmt = conf_stpcpy (conf_format, conf_unexpected);

	  for (conf_x = conf_xbegin; conf_x < conf_xend; ++conf_x)
	    if (conf_check[conf_x + conf_n] == conf_x && conf_x != YYTERROR)
	      {
		if (conf_count == YYERROR_VERBOSE_ARGS_MAXIMUM)
		  {
		    conf_count = 1;
		    conf_size = conf_size0;
		    conf_format[sizeof conf_unexpected - 1] = '\0';
		    break;
		  }
		conf_arg[conf_count++] = conf_tname[conf_x];
		conf_size1 = conf_size + conf_tnamerr (0, conf_tname[conf_x]);
		conf_size_overflow |= conf_size1 < conf_size;
		conf_size = conf_size1;
		conf_fmt = conf_stpcpy (conf_fmt, conf_prefix);
		conf_prefix = conf_or;
	      }

	  conf_f = YY_(conf_format);
	  conf_size1 = conf_size + conf_strlen (conf_f);
	  conf_size_overflow |= conf_size1 < conf_size;
	  conf_size = conf_size1;

	  if (!conf_size_overflow && conf_size <= YYSTACK_ALLOC_MAXIMUM)
	    conf_msg = (char *) YYSTACK_ALLOC (conf_size);
	  if (conf_msg)
	    {
	      /* Avoid sprintf, as that infringes on the user's name space.
		 Don't have undefined behavior even if the translation
		 produced a string with the wrong number of "%s"s.  */
	      char *conf_p = conf_msg;
	      int conf_i = 0;
	      while ((*conf_p = *conf_f))
		{
		  if (*conf_p == '%' && conf_f[1] == 's' && conf_i < conf_count)
		    {
		      conf_p += conf_tnamerr (conf_p, conf_arg[conf_i++]);
		      conf_f += 2;
		    }
		  else
		    {
		      conf_p++;
		      conf_f++;
		    }
		}
	      conf_error (conf_msg);
	      YYSTACK_FREE (conf_msg);
	    }
	  else
	    {
	      conf_error (YY_("syntax error"));
	      goto conf_exhaustedlab;
	    }
	}
      else
#endif /* YYERROR_VERBOSE */
	conf_error (YY_("syntax error"));
    }



  if (conf_errstatus == 3)
    {
      /* If just tried and failed to reuse look-ahead token after an
	 error, discard it.  */

      if (conf_char <= YYEOF)
        {
	  /* Return failure if at end of input.  */
	  if (conf_char == YYEOF)
	    YYABORT;
        }
      else
	{
	  conf_destruct ("Error: discarding", conf_token, &conf_lval);
	  conf_char = YYEMPTY;
	}
    }

  /* Else will try to reuse look-ahead token after shifting the error
     token.  */
  goto conf_errlab1;


/*---------------------------------------------------.
| conf_errorlab -- error raised explicitly by YYERROR.  |
`---------------------------------------------------*/
conf_errorlab:

  /* Pacify compilers like GCC when the user code never invokes
     YYERROR and the label conf_errorlab therefore never appears in user
     code.  */
  if (0)
     goto conf_errorlab;

conf_vsp -= conf_len;
  conf_ssp -= conf_len;
  conf_state = *conf_ssp;
  goto conf_errlab1;


/*-------------------------------------------------------------.
| conf_errlab1 -- common code for both syntax error and YYERROR.  |
`-------------------------------------------------------------*/
conf_errlab1:
  conf_errstatus = 3;	/* Each real token shifted decrements this.  */

  for (;;)
    {
      conf_n = conf_pact[conf_state];
      if (conf_n != YYPACT_NINF)
	{
	  conf_n += YYTERROR;
	  if (0 <= conf_n && conf_n <= YYLAST && conf_check[conf_n] == YYTERROR)
	    {
	      conf_n = conf_table[conf_n];
	      if (0 < conf_n)
		break;
	    }
	}

      /* Pop the current state because it cannot handle the error token.  */
      if (conf_ssp == conf_ss)
	YYABORT;


      conf_destruct ("Error: popping", conf_stos[conf_state], conf_vsp);
      YYPOPSTACK;
      conf_state = *conf_ssp;
      YY_STACK_PRINT (conf_ss, conf_ssp);
    }

  if (conf_n == YYFINAL)
    YYACCEPT;

  *++conf_vsp = conf_lval;


  /* Shift the error token. */
  YY_SYMBOL_PRINT ("Shifting", conf_stos[conf_n], conf_vsp, conf_lsp);

  conf_state = conf_n;
  goto conf_newstate;


/*-------------------------------------.
| conf_acceptlab -- YYACCEPT comes here.  |
`-------------------------------------*/
conf_acceptlab:
  conf_result = 0;
  goto conf_return;

/*-----------------------------------.
| conf_abortlab -- YYABORT comes here.  |
`-----------------------------------*/
conf_abortlab:
  conf_result = 1;
  goto conf_return;

#ifndef conf_overflow
/*-------------------------------------------------.
| conf_exhaustedlab -- memory exhaustion comes here.  |
`-------------------------------------------------*/
conf_exhaustedlab:
  conf_error (YY_("memory exhausted"));
  conf_result = 2;
  /* Fall through.  */
#endif

conf_return:
  if (conf_char != YYEOF && conf_char != YYEMPTY)
     conf_destruct ("Cleanup: discarding lookahead",
		 conf_token, &conf_lval);
  while (conf_ssp != conf_ss)
    {
      conf_destruct ("Cleanup: popping",
		  conf_stos[*conf_ssp], conf_vsp);
      YYPOPSTACK;
    }
#ifndef conf_overflow
  if (conf_ss != conf_ssa)
    YYSTACK_FREE (conf_ss);
#endif
  return conf_result;
}


#line 148 "conf_parse.y"


static int
conf_error(const char *s)
{
  fprintf(stderr, "AMDCONF: %s on line %d (section %s)\n",
	  s, aconf_lineno,
	  (header_section ? header_section : "null"));
  exit(1);
  return 1;	/* to full compilers that insist on a return statement */
}

